@@ -1301,7 +1301,7 @@ function [tx_bits payload_data_bits codeword] = create_ldpc_test_frame(states, c
 
     mod_order = 4; bps = 2; modulation = 'QPSK'; mapping = 'gray';
 
-    init_cml('~/cml/'); % TODO: make this path sensible and portable
+    init_cml(); % TODO: make this path sensible and portable
     load HRA_112_112.txt
     [code_param framesize rate] = ldpc_init_user(HRA_112_112, modulation, mod_order, mapping);
     assert(Nbitsperframe == (code_param.coded_bits_per_frame + Nuwbits + Ntxtbits));
@@ -1643,7 +1643,7 @@ function [code_param Nbitspercodecframe Ncodecframespermodemframe] = codec_to_fr
   ofdm_load_const;
   mod_order = 4; bps = 2; modulation = 'QPSK'; mapping = 'gray';
 
-  init_cml('~/cml/');
+  init_cml();
   if strcmp(mode, "700D")
     load HRA_112_112.txt
     code_param = ldpc_init_user(HRA_112_112, modulation, mod_order, mapping);
