@@ -37,5 +37,7 @@ void gp_interleave_comp(COMP interleaved_frame[], COMP frame[], int Nbits);
 void gp_deinterleave_comp(COMP frame[], COMP interleaved_frame[], int Nbits);
 void gp_interleave_float(float frame[], float interleaved_frame[], int Nbits);
 void gp_deinterleave_float(float interleaved_frame[], float frame[], int Nbits);
+void gp_interleave_bits(char interleaved_frame[], char frame[], int Nbits);
+void gp_deinterleave_bits(char frame[], char interleaved_frame[], int Nbits);
 
 #endif
