@@ -14,20 +14,11 @@
 #   $ PATH=$PATH:../build_linux/src ./ofdm_phase_est_bw.sh
 
 results=$(mktemp)
-
-# generate fading file
-if [ ! -f ../raw/fast_fading_samples.float ]; then
-    echo "Generating fading file ......"
-    cmd='cd ../octave; pkg load signal; cohpsk_ch_fading("../raw/fast_fading_samples.float", 8000, 1.0, 8000*60)'
-    octave --no-gui -qf --eval "$cmd"
-    [ ! $? -eq 0 ] && { echo "octave failed to run correctly .... exiting"; exit 1; }
-fi
-
-pwd
+fading_dir=$1
 # BER should be < 5% for this test
 ofdm_mod --in /dev/zero --testframes 300 --mode 2020 --ldpc -p 312 --verbose 0 | \
-cohpsk_ch - - -40 --Fs 8000 -f 10 --ssbfilt 1 --mpp --raw_dir ../raw | \
+cohpsk_ch - - -40 --Fs 8000 -f 10 --ssbfilt 1 --mpp --fading_dir $fading_dir | \
 ofdm_demod --out /dev/null --testframes --mode 2020 --verbose 2 --ldpc -p 312 --bandwidth 1 2> $results
 cat $results
 cber=$(cat $results | sed -n "s/^Coded BER.* \([0-9..]*\) Tbits.*/\1/p")
-python -c "import sys; sys.exit(0) if $cber<=0.05 else sys.exit(1)"
+python3 -c "import sys; sys.exit(0) if $cber<=0.05 else sys.exit(1)"
